pub trait MulticallInterface {
// Required method
fn multicall(env: &Env, function_calls: Vec<FunctionCall>) -> Vec<Val>;
}Required Methods
Sourcefn multicall(env: &Env, function_calls: Vec<FunctionCall>) -> Vec<Val>
fn multicall(env: &Env, function_calls: Vec<FunctionCall>) -> Vec<Val>
Executes an arbitrary list of contract calls and returns the results of all the calls.
Arguments
function_calls- A list of params containing the contract address, function name and arguments for each contract call.
Returns
Ok(Vec<Val>): Returns a vector with the return data of each function call
Errors:
- Propagates any error that occurs during the execution of the contract calls.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".