pub struct FunctionCall {
pub contract: Address,
pub approver: Address,
pub function: Symbol,
pub args: Vec<Val>,
}Fields
contract: Addressapprover: AddressThere must be an address authorizing each function call, even if the function call itself doesn’t need authorization, to prevent frontrunning of individual calls within a multicall
function: Symbolargs: Vec<Val>Implementations